Name:       miniz
Version:    3.0.2
Release:    1%{?dist}
Summary:    Compression library implementing the zlib and Deflate
License:    MIT AND Unlicense
URL:        https://github.com/richgel999/%{name}
Source0:    %{url}/releases/download/%{version}/%{name}-%{version}.zip
Patch0:     miniz-2.2.0-Examples-to-include-system-miniz.h.patch
BuildRequires:  coreutils
BuildRequires:  diffutils
%if "%{toolchain}" == "gcc"
BuildRequires:  gcc
%else
%if "%{toolchain}" == "clang"
BuildRequires:  clang
%else
%endif
%endif
BuildRequires:  sed
BuildRequires:  unzip

%description
Miniz is a lossless, high performance data compression library in a single
source file that implements the zlib (RFC 1950) and Deflate (RFC 1951)
compressed data format specification standards. It supports the most commonly
used functions exported by the zlib library, but is a completely independent
implementation so zlib's licensing requirements do not apply. It also
contains simple to use functions for writing PNG format image files and
reading/writing/appending ZIP format archives. Miniz's compression speed has
been tuned to be comparable to zlib's, and it also has a specialized real-time
compressor function designed to compare well against fastlz/minilzo.

%package devel
Summary:    Development files for the %{name} library
Requires:   %{name} = %{version}-%{release}

%description devel
Header files for developing applications that use the %{name} library.


%prep
%setup -c -T -n %{name}-%{version}
unzip -e '%{SOURCE0}'
%patch0 -p1
sed -e 's/\r$//' ChangeLog.md > ChangeLog.md.new
touch -r ChangeLog.md ChangeLog.md.new
mv ChangeLog.md.new ChangeLog.md

%global soname lib%{name}.so.0.3

%build
%define build_cc cc
%{build_cc} %{optflags} -fPIC -DPIC -D_LARGEFILE64_SOURCE=1 -D_FILE_OFFSET_BITS=64 \
    %{name}.c -c -o %{name}.o
%{build_cc} %{?__global_ldflags} -fPIC -shared -Wl,-soname,%{soname} \
    %{name}.o -o %{soname}
ln -s %{soname} lib%{name}.so
pushd examples
for EXAMPLE in *.c; do
    EXAMPLE=${EXAMPLE%.c}
    %{build_cc} %{optflags} -D_LARGEFILE64_SOURCE=1 -D_FILE_OFFSET_BITS=64 \
        -I.. "${EXAMPLE}.c" -c -o "${EXAMPLE}.o"
    case "$EXAMPLE" in
        example6)
            %{build_cc} %{?__global_ldflags} "${EXAMPLE}.o" -L.. -l%{name} -lm -o "$EXAMPLE"
            ;;
        *)
            %{build_cc} %{?__global_ldflags} "${EXAMPLE}.o" -L.. -l%{name} -o "$EXAMPLE"
            ;;
    esac
done

%check
pushd examples
for EXAMPLE in *.c; do
    EXAMPLE=${EXAMPLE%.c}
    case "$EXAMPLE" in
        example3)
            LD_LIBRARY_PATH=.. "./${EXAMPLE}" c ../readme.md readme.md.z
            LD_LIBRARY_PATH=.. "./${EXAMPLE}" d readme.md.z readme.md
            cmp ../readme.md readme.md
            ;;
        example4)
            LD_LIBRARY_PATH=.. "./${EXAMPLE}" readme.md.z readme.md
            cmp ../readme.md readme.md
            ;;
        example5)
            LD_LIBRARY_PATH=.. "./${EXAMPLE}" c ../readme.md readme.md.z
            LD_LIBRARY_PATH=.. "./${EXAMPLE}" d readme.md.z readme.md
            cmp ../readme.md readme.md
            ;;
        *)
            LD_LIBRARY_PATH=.. "./${EXAMPLE}"
            ;;
    esac
done

%install
install -d '%{buildroot}/%{_libdir}'
install %{soname} '%{buildroot}/%{_libdir}'
ln -s %{soname} '%{buildroot}/%{_libdir}/lib%{name}.so'
install -d '%{buildroot}/%{_includedir}'
install -m 0644 %{name}.h '%{buildroot}/%{_includedir}'

%files
%license LICENSE
%doc ChangeLog.md readme.md
%{_libdir}/%{soname}

%files devel
%doc examples/*.c
%{_includedir}/%{name}.h
%{_libdir}/lib%{name}.so


%changelog
* Mon Apr 15 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.0.2-1
- initial build
